@@ -9,8 +9,8 @@ mod lex;
 mod lossless;
 mod parse;
 pub use lossless::{
-    Deb822, Entry, Error, Lang, Paragraph, ParseError, PositionedParseError, BINARY_FIELD_ORDER,
-    SOURCE_FIELD_ORDER,
+    Deb822, Entry, Error, IndentPattern, Lang, Paragraph, ParseError, PositionedParseError,
+    BINARY_FIELD_ORDER, SOURCE_FIELD_ORDER,
 };
 pub use parse::Parse;
 pub use rowan::TextRange;
